# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKMeshPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkVTKPolyDataReaderPython
else:
    import _itkVTKPolyDataReaderPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkMeshBasePython
import itk.itkPointSetPython
import itk.itkVectorContainerPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkContinuousIndexPython
import itk.itkIndexPython
import itk.itkArrayPython
import itk.itkBoundingBoxPython
import itk.itkMapContainerPython

def itkVTKPolyDataReaderMD2_Superclass_New():
    return itkVTKPolyDataReaderMD2_Superclass.New()

class itkVTKPolyDataReaderMD2_Superclass(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkVTKPolyDataReaderMD2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVTKPolyDataReaderMD2_Superclass_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVTKPolyDataReaderMD2_Superclass_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_Superclass_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshD2
        GetOutput(self, idx) -> itkMeshD2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_Superclass_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshD2 *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_Superclass_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_Superclass_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_Superclass_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkVTKPolyDataReaderPython.delete_itkVTKPolyDataReaderMD2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVTKPolyDataReaderMD2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVTKPolyDataReaderMD2_Superclass

        Create a new object of the class itkVTKPolyDataReaderMD2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVTKPolyDataReaderMD2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVTKPolyDataReaderMD2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVTKPolyDataReaderMD2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVTKPolyDataReaderMD2_Superclass in _itkVTKPolyDataReaderPython:
_itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_Superclass_swigregister(itkVTKPolyDataReaderMD2_Superclass)

def itkVTKPolyDataReaderMD3_Superclass_New():
    return itkVTKPolyDataReaderMD3_Superclass.New()

class itkVTKPolyDataReaderMD3_Superclass(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkVTKPolyDataReaderMD3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVTKPolyDataReaderMD3_Superclass_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVTKPolyDataReaderMD3_Superclass_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_Superclass_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshD3
        GetOutput(self, idx) -> itkMeshD3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_Superclass_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshD3 *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_Superclass_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_Superclass_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_Superclass_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkVTKPolyDataReaderPython.delete_itkVTKPolyDataReaderMD3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVTKPolyDataReaderMD3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVTKPolyDataReaderMD3_Superclass

        Create a new object of the class itkVTKPolyDataReaderMD3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVTKPolyDataReaderMD3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVTKPolyDataReaderMD3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVTKPolyDataReaderMD3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVTKPolyDataReaderMD3_Superclass in _itkVTKPolyDataReaderPython:
_itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_Superclass_swigregister(itkVTKPolyDataReaderMD3_Superclass)

def itkVTKPolyDataReaderMF2_Superclass_New():
    return itkVTKPolyDataReaderMF2_Superclass.New()

class itkVTKPolyDataReaderMF2_Superclass(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkVTKPolyDataReaderMF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVTKPolyDataReaderMF2_Superclass_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVTKPolyDataReaderMF2_Superclass_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_Superclass_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshF2
        GetOutput(self, idx) -> itkMeshF2

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_Superclass_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshF2 *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_Superclass_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_Superclass_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_Superclass_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkVTKPolyDataReaderPython.delete_itkVTKPolyDataReaderMF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVTKPolyDataReaderMF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVTKPolyDataReaderMF2_Superclass

        Create a new object of the class itkVTKPolyDataReaderMF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVTKPolyDataReaderMF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVTKPolyDataReaderMF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVTKPolyDataReaderMF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVTKPolyDataReaderMF2_Superclass in _itkVTKPolyDataReaderPython:
_itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_Superclass_swigregister(itkVTKPolyDataReaderMF2_Superclass)

def itkVTKPolyDataReaderMF3_Superclass_New():
    return itkVTKPolyDataReaderMF3_Superclass.New()

class itkVTKPolyDataReaderMF3_Superclass(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkVTKPolyDataReaderMF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVTKPolyDataReaderMF3_Superclass_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVTKPolyDataReaderMF3_Superclass_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_Superclass_Clone(self)

    def GetOutput(self, *args):
        r"""
        GetOutput(self) -> itkMeshF3
        GetOutput(self, idx) -> itkMeshF3

        Parameters
        ----------
        idx: unsigned int

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_Superclass_GetOutput(self, *args)

    def SetOutput(self, output):
        r"""
        SetOutput(self, output)

        Parameters
        ----------
        output: itkMeshF3 *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_Superclass_SetOutput(self, output)

    def GraftOutput(self, *args):
        r"""
        GraftOutput(self, graft)

        Parameters
        ----------
        graft: itkDataObject *

        GraftOutput(self, key, graft)

        Parameters
        ----------
        key: std::string const &
        graft: itkDataObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_Superclass_GraftOutput(self, *args)

    def GraftNthOutput(self, idx, graft):
        r"""
        GraftNthOutput(self, idx, graft)

        Parameters
        ----------
        idx: unsigned int
        graft: itkDataObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_Superclass_GraftNthOutput(self, idx, graft)
    __swig_destroy__ = _itkVTKPolyDataReaderPython.delete_itkVTKPolyDataReaderMF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVTKPolyDataReaderMF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVTKPolyDataReaderMF3_Superclass

        Create a new object of the class itkVTKPolyDataReaderMF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVTKPolyDataReaderMF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVTKPolyDataReaderMF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVTKPolyDataReaderMF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVTKPolyDataReaderMF3_Superclass in _itkVTKPolyDataReaderPython:
_itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_Superclass_swigregister(itkVTKPolyDataReaderMF3_Superclass)

def itkVTKPolyDataReaderMD2_New():
    return itkVTKPolyDataReaderMD2.New()

class itkVTKPolyDataReaderMD2(itkVTKPolyDataReaderMD2_Superclass):
    r"""Proxy of C++ itkVTKPolyDataReaderMD2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVTKPolyDataReaderMD2_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVTKPolyDataReaderMD2_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_Clone(self)

    def SetFileName(self, *args):
        r"""
        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: char const *

        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: std::string const &

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_SetFileName(self, *args)

    def GetFileName(self):
        r"""GetFileName(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_GetFileName(self)

    def GetVersion(self):
        r"""GetVersion(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_GetVersion(self)

    def GetHeader(self):
        r"""GetHeader(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_GetHeader(self)
    __swig_destroy__ = _itkVTKPolyDataReaderPython.delete_itkVTKPolyDataReaderMD2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVTKPolyDataReaderMD2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVTKPolyDataReaderMD2

        Create a new object of the class itkVTKPolyDataReaderMD2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVTKPolyDataReaderMD2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVTKPolyDataReaderMD2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVTKPolyDataReaderMD2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVTKPolyDataReaderMD2 in _itkVTKPolyDataReaderPython:
_itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD2_swigregister(itkVTKPolyDataReaderMD2)

def itkVTKPolyDataReaderMD3_New():
    return itkVTKPolyDataReaderMD3.New()

class itkVTKPolyDataReaderMD3(itkVTKPolyDataReaderMD3_Superclass):
    r"""Proxy of C++ itkVTKPolyDataReaderMD3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVTKPolyDataReaderMD3_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVTKPolyDataReaderMD3_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_Clone(self)

    def SetFileName(self, *args):
        r"""
        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: char const *

        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: std::string const &

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_SetFileName(self, *args)

    def GetFileName(self):
        r"""GetFileName(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_GetFileName(self)

    def GetVersion(self):
        r"""GetVersion(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_GetVersion(self)

    def GetHeader(self):
        r"""GetHeader(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_GetHeader(self)
    __swig_destroy__ = _itkVTKPolyDataReaderPython.delete_itkVTKPolyDataReaderMD3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVTKPolyDataReaderMD3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVTKPolyDataReaderMD3

        Create a new object of the class itkVTKPolyDataReaderMD3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVTKPolyDataReaderMD3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVTKPolyDataReaderMD3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVTKPolyDataReaderMD3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVTKPolyDataReaderMD3 in _itkVTKPolyDataReaderPython:
_itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMD3_swigregister(itkVTKPolyDataReaderMD3)

def itkVTKPolyDataReaderMF2_New():
    return itkVTKPolyDataReaderMF2.New()

class itkVTKPolyDataReaderMF2(itkVTKPolyDataReaderMF2_Superclass):
    r"""Proxy of C++ itkVTKPolyDataReaderMF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVTKPolyDataReaderMF2_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVTKPolyDataReaderMF2_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_Clone(self)

    def SetFileName(self, *args):
        r"""
        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: char const *

        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: std::string const &

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_SetFileName(self, *args)

    def GetFileName(self):
        r"""GetFileName(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_GetFileName(self)

    def GetVersion(self):
        r"""GetVersion(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_GetVersion(self)

    def GetHeader(self):
        r"""GetHeader(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_GetHeader(self)
    __swig_destroy__ = _itkVTKPolyDataReaderPython.delete_itkVTKPolyDataReaderMF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVTKPolyDataReaderMF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVTKPolyDataReaderMF2

        Create a new object of the class itkVTKPolyDataReaderMF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVTKPolyDataReaderMF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVTKPolyDataReaderMF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVTKPolyDataReaderMF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVTKPolyDataReaderMF2 in _itkVTKPolyDataReaderPython:
_itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF2_swigregister(itkVTKPolyDataReaderMF2)

def itkVTKPolyDataReaderMF3_New():
    return itkVTKPolyDataReaderMF3.New()

class itkVTKPolyDataReaderMF3(itkVTKPolyDataReaderMF3_Superclass):
    r"""Proxy of C++ itkVTKPolyDataReaderMF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkVTKPolyDataReaderMF3_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkVTKPolyDataReaderMF3_Pointer"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_Clone(self)

    def SetFileName(self, *args):
        r"""
        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: char const *

        SetFileName(self, _arg)

        Parameters
        ----------
        _arg: std::string const &

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_SetFileName(self, *args)

    def GetFileName(self):
        r"""GetFileName(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_GetFileName(self)

    def GetVersion(self):
        r"""GetVersion(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_GetVersion(self)

    def GetHeader(self):
        r"""GetHeader(self) -> char const *"""
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_GetHeader(self)
    __swig_destroy__ = _itkVTKPolyDataReaderPython.delete_itkVTKPolyDataReaderMF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkVTKPolyDataReaderMF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkVTKPolyDataReaderMF3

        Create a new object of the class itkVTKPolyDataReaderMF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkVTKPolyDataReaderMF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkVTKPolyDataReaderMF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkVTKPolyDataReaderMF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkVTKPolyDataReaderMF3 in _itkVTKPolyDataReaderPython:
_itkVTKPolyDataReaderPython.itkVTKPolyDataReaderMF3_swigregister(itkVTKPolyDataReaderMF3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def mesh_source(*args,  output: itkt.Mesh=...,**kwargs):
    """Functional interface for MeshSource"""
    import itk

    kwarg_typehints = { 'output':output }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.MeshSource.New(*args, **kwargs)

    return instance.__internal_call__()

def mesh_source_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKMesh.MeshSource
    mesh_source.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    mesh_source.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def vtk_poly_data_reader(*args,  file_name: str=..., output: itkt.Mesh=...,**kwargs)-> itkt.MeshSourceReturn:
    """Functional interface for VTKPolyDataReader"""
    import itk

    kwarg_typehints = { 'file_name':file_name,'output':output }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.VTKPolyDataReader.New(*args, **kwargs)

    return instance.__internal_call__()

def vtk_poly_data_reader_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKMesh.VTKPolyDataReader
    vtk_poly_data_reader.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    vtk_poly_data_reader.__doc__ = filter_object.__doc__



